@@ -3,7 +3,7 @@ package Net::AMQP::RabbitMQ::PP;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Carp;
 use Cwd;
@@ -431,8 +431,9 @@ sub _receive_delivery {
 	}
 
 	return (
-		content_header_frame => $headerframe,
-		payload => $payload,
+        content_header_frame => $headerframe,
+        payload => $payload,
+        ( $args{delivery_tag} ? ( delivery_tag => $args{delivery_tag} ) : () )
 	);
 }
 
@@ -723,9 +724,11 @@ sub basic_get {
 		return;
 	}
 	else {
+        my $delivery_tag = $get->delivery_tag;
 		return {
 			$self->_receive_delivery(
-				channel => $channel,
+				channel      => $channel,
+                delivery_tag => $delivery_tag,
 			),
 		}
 	}
@@ -913,7 +916,7 @@ Like L<Net::RabbitMQ> but pure perl rather than a wrapper around librabbitmq.
 
 =head1 VERSION
 
-0.3
+0.04
 
 =head1 SUBROUTINES/METHODS
 
@@ -1185,6 +1188,10 @@ Current maintainer:
 
 	leejo@cpan.org
 
+Contributors:
+
+    Ben Kaufman
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2013 Eugene Marcotte
